@@ -7,7 +7,7 @@ use super::DefaultVisitorContext;
 
 /// A trait for implenenting a visitor for GraphQL operations.
 /// It allow your custom function to be called when an AST node is found.
-/// 
+///
 /// You can pass custom <T> as context if you need to store data / access external variables.
 pub trait QueryVisitor<T = DefaultVisitorContext> {
     fn visit_document(&self, node: &Document, visitor_context: &mut T) {
@@ -162,14 +162,14 @@ pub trait QueryVisitor<T = DefaultVisitorContext> {
         &self,
         _node: &VariableDefinition,
         _parent_operation: &OperationDefinition,
-        _visitor_context: &T,
+        _visitor_context: &mut T,
     ) {
     }
     fn leave_variable_definition(
         &self,
         _node: &VariableDefinition,
         _parent_operation: &OperationDefinition,
-        _visitor_context: &T,
+        _visitor_context: &mut T,
     ) {
     }
 
@@ -184,7 +184,7 @@ pub trait QueryVisitor<T = DefaultVisitorContext> {
         _name: &String,
         _value: &Value,
         _parent_field: &Field,
-        _visitor_context: &T,
+        _visitor_context: &mut T,
     ) {
     }
     fn leave_field_argument(
@@ -192,7 +192,7 @@ pub trait QueryVisitor<T = DefaultVisitorContext> {
         _name: &String,
         _value: &Value,
         _parent_field: &Field,
-        _visitor_context: &T,
+        _visitor_context: &mut T,
     ) {
     }
 
